@@ -4,18 +4,7 @@ from mptt.admin import FeinCMSModelAdmin
 from django_zen.models import Menu, Page
 
 
-class AppLabelAdminMixin(object):
-    def render_change_form(self, request, context, add=False, change=False, form_url='', obj=None):
-        context['app_label'] = self.model._meta.app_label.title()
-        return super(AppLabelAdminMixin, self).render_change_form(request, context, add, change, form_url, obj)
-
-    def changelist_view(self, request, extra_context=None):
-        extra_context = extra_context or {}
-        extra_context['app_label'] = self.model._meta.app_label.title()
-        return super(AppLabelAdminMixin, self).changelist_view(request, extra_context)
-
-
-class PagesAdmin(admin.ModelAdmin, AppLabelAdminMixin):
+class PagesAdmin(admin.ModelAdmin):
     list_display = ('url', 'title', 'published')
 
     def save_model(self, request, obj, form, change):
@@ -37,7 +26,7 @@ class PagesAdmin(admin.ModelAdmin, AppLabelAdminMixin):
     ]
 
 
-class MenuAdmin(FeinCMSModelAdmin, AppLabelAdminMixin):
+class MenuAdmin(FeinCMSModelAdmin):
     list_display = ('name', 'url', 'menu_id', 'published')
 
     fieldsets = [
